==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Edit/ts/Edit_sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>AbstractPreferences</name>
    <message>
        <location filename="../AbstractPreferences.js" line="+46"/>
        <source>Application Preferences</source>
        <translation>Nastavenia Programu</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Drawing Preferences</source>
        <translation>Nastavenia Kreslenia</translation>
    </message>
    <message>
        <location line="+312"/>
        <source>Restart required</source>
        <translation>Vyžaduje reštart</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Please restart QCAD for
the preference changes to take effect.</source>
        <translation>Aby sa zmeny v nastavení prejavili
musíte znovu spustiť QCAD.</translation>
    </message>
</context>
<context>
    <name>ClipboardOperation</name>
    <message>
        <location filename="../ClipboardOperation.js" line="+52"/>
        <source>Reference point</source>
        <translation>Referenčný bod</translation>
    </message>
</context>
<context>
    <name>Edit</name>
    <message>
        <location filename="../Edit.js" line="+65"/>
        <source>Edit Tools</source>
        <translation>Nástroje Úpravy</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show edit tools</source>
        <translation>Zobraziť nástroje úpravy</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;Edit</source>
        <translation>&amp;Upraviť</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../AbstractPreferences.ui" line="+14"/>
        <location line="+85"/>
        <location line="+21"/>
        <source>Preferences</source>
        <translation>Nastavenia</translation>
    </message>
    <message>
        <location line="-88"/>
        <source>Filter</source>
        <translation>Filter</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Clear Search</source>
        <translation>Vyčistiť hľadanie</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Expand Tree</source>
        <translation>Rozbaliť Strom</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Collapse Tree</source>
        <translation>Zbaliť Strom</translation>
    </message>
    <message>
        <location line="+67"/>
        <source>Restore to Default Values</source>
        <translation>Obnoviť predvolené hodnoty</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Edit/ts/Edit_sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>AbstractPreferences</name>
    <message>
        <location filename="../AbstractPreferences.js" line="+46"/>
        <source>Application Preferences</source>
        <translation>Nastavenia Programu</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Drawing Preferences</source>
        <translation>Nastavenia Kreslenia</translation>
    </message>
    <message>
        <location line="+300"/>
        <source>Apply preferences</source>
        <translation>Použiť nastavenia</translation>
    </message>
    <message>
        <location line="+45"/>
        <source>Restart required</source>
        <translation>Vyžaduje reštart</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Please restart QCAD for
the preference changes to take effect.</source>
        <translation>Aby sa zmeny v nastavení prejavili
musíte znovu spustiť QCAD.</translation>
    </message>
    <message>
        <location line="+86"/>
        <source>Defaults for </source>
        <translation>Predvolené</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>These are default preferences for new drawings.</source>
        <translation>Toto sú predvolené nastavenia pre nový výkres.</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Preferences of the current drawing can be changed under&lt;br/&gt;&lt;i&gt;Edit &amp;gt; Drawing Preferences&lt;/i&gt;.</source>
        <translation>Nastavenia aktuálneho výkresu môžu byť zmenené pod&lt;br/&gt;&lt;i&gt;Upraviť &amp;gt; Nastavenia kreslenia&lt;/i&gt;.</translation>
    </message>
    <message>
        <location line="-1"/>
        <source>Changes will affect new drawings but NOT the current drawing.</source>
        <translation>Zmeny sa dotknú nových výkresov, ale nie aktuálneho výkresu.</translation>
    </message>
</context>
<context>
    <name>ClipboardOperation</name>
    <message>
        <location filename="../ClipboardOperation.js" line="+52"/>
        <source>Reference point</source>
        <translation>Referenčný bod</translation>
    </message>
</context>
<context>
    <name>Edit</name>
    <message>
        <location filename="../Edit.js" line="+65"/>
        <source>Edit Tools</source>
        <translation>Nástroje Úpravy</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show edit tools</source>
        <translation>Zobraziť nástroje úpravy</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;Edit</source>
        <translation>&amp;Upraviť</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../AbstractPreferences.ui" line="+14"/>
        <location line="+71"/>
        <location line="+21"/>
        <source>Preferences</source>
        <translation>Nastavenia</translation>
    </message>
    <message>
        <location line="-74"/>
        <source>Filter</source>
        <translation>Filter</translation>
    </message>
    <message>
        <source>Clear Search</source>
        <translation type="vanished">Vyčistiť hľadanie</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Expand Tree</source>
        <translation>Rozbaliť Strom</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Collapse Tree</source>
        <translation>Zbaliť Strom</translation>
    </message>
    <message>
        <location line="+67"/>
        <source>Restore to Default Values</source>
        <translation>Obnoviť predvolené hodnoty</translation>
    </message>
</context>
</TS>
